This is an automated email from the git hooks/post-receive script.

guix_mirror_bot pushed a commit to branch master
in repository guix.

The following commit(s) were added to refs/heads/master by this push:
     new 6861d60b87 gnu: emacs-gnosis: Update to 0.8.0.
6861d60b87 is described below

commit 6861d60b87d03d9cea91234999613f167d8a96dd
Author: Thanos Apollo <[email protected]>
AuthorDate: Thu Mar 5 16:35:42 2026 +0200

    gnu: emacs-gnosis: Update to 0.8.0.
    
    * gnu/packages/emacs-xyz.scm (emacs-gnosis): Update to 0.8.0.
    [arguments]: Use emacs-no-x instead of emacs.  Update make test and doc
    commands as upstream Makefile now wraps commands with `guix shell`.
    [home-page]: Add trailing slash.
    
    Merges guix/guix!6908
    
    Change-Id: I532b0ae1ec7177f62c6b33f6c6c81f20ef2fae4d
    Signed-off-by: Cayetano Santos <[email protected]>
---
 gnu/packages/emacs-xyz.scm | 36 ++++++++++++++++++++----------------
 1 file changed, 20 insertions(+), 16 deletions(-)

diff --git a/gnu/packages/emacs-xyz.scm b/gnu/packages/emacs-xyz.scm
index 370b1fa99a..abd8addd43 100644
--- a/gnu/packages/emacs-xyz.scm
+++ b/gnu/packages/emacs-xyz.scm
@@ -22172,7 +22172,7 @@ are common in Chromium-derived projects.")
 (define-public emacs-gnosis
   (package
     (name "emacs-gnosis")
-    (version "0.5.7")
+    (version "0.8.0")
     (source
      (origin
        (method git-fetch)
@@ -22181,23 +22181,27 @@ are common in Chromium-derived projects.")
               (commit version)))
        (file-name (git-file-name name version))
        (sha256
-        (base32 "1nzyys00jdh1d7sv8jigaxb1h1ghvkc9d1r0603rsmfkrsfq229p"))))
+        (base32 "003pmd0ahpcss5ydk3wbx5j45225ypa85zrgljz5qajijiybvxpi"))))
     (build-system emacs-build-system)
-    (arguments (list #:test-command #~(list "make" "test")
-                     #:emacs emacs   ; tests require built-in SQLite support
-                     #:phases
-                     #~(modify-phases %standard-phases
-                         (add-before 'check 'set-home
-                           (lambda _
-                             (setenv "HOME" (getenv "TMPDIR"))
-                             (mkdir-p (string-append (getenv "HOME")
-                                                     "/.emacs.d"))))
-                         (add-before 'install 'make-info
-                           (lambda _ (invoke "make" "doc"))))))
+    (arguments
+     (list
+      #:test-command
+      #~(list "make" "test" "GUIX_SHELL=")
+      #:emacs emacs-no-x ;tests require built-in SQLite support
+      #:phases
+      #~(modify-phases %standard-phases
+          (add-before 'check 'set-home
+            (lambda _
+              (setenv "HOME"
+                      (getenv "TMPDIR"))
+              (mkdir-p (string-append (getenv "HOME") "/.emacs.d"))))
+          (add-before 'install 'make-info
+            (lambda _
+              (invoke "make" "doc" "GUIX_SHELL="))))))
     (native-inputs (list texinfo))
-    (propagated-inputs
-     (list emacs-compat emacs-emacsql emacs-org-gnosis emacs-transient))
-    (home-page "https://thanosapollo.org/projects/gnosis";)
+    (propagated-inputs (list emacs-compat emacs-emacsql emacs-org-gnosis
+                             emacs-transient))
+    (home-page "https://thanosapollo.org/projects/gnosis/";)
     (synopsis "Spaced repetition system for GNU Emacs")
     (description
      "Gnosis is a spaced repetition system for note-taking and self-testing

Reply via email to